Referencia completa
===================

.. toctree::
   :maxdepth: 2

   core.rst
   readers.rst
   writers.rst
   validation.rst
   search.rst
   indicators_list.rst
   reporting.rst
   federation.rst
   backup.rst


